cordova.define("cordova-plugin-proper-properpush.Properpush", function(require, exports, module) {
function Properpush() {}
Properpush.prototype.openNotification = {}
/**
 * 初始化推送
 * kvs 为传入的参数json
 *   appId: 推送应用的标识
 *   pushUrl:推送对应的url地址
 * @param {Object} kvs
 * @param {Object} successCallback
 * @param {Object} errorCallback
 */
Properpush.prototype.init = function(kvs, successCallback, errorCallback) {
	cordova.exec(successCallback, errorCallback, "Properpush", "init", [kvs]);
};
/**
 * 当前设备绑定用户id,与业务上的用户关联起来
 * kvs 为传入的参数json
 *   userid: 用户的ID
 *   otherInfo:其它和用户相关的信息
 * @param {Object} kvs
 * @param {Object} successCallback
 * @param {Object} errorCallback
 */
Properpush.prototype.bindUserid = function(kvs, successCallback, errorCallback) {
	cordova.exec(successCallback, errorCallback, "Properpush", "bindUserid", [kvs]);
};
/**
 * 获取设备信息，返回一个json对象
 * type :"android","ios"
 * jsonStr: 其它设备信息，json字符串，不同的平台返回的信息不同
 * @param {Object} successCallback 
 * @param {Object} errorCallback
 */
Properpush.prototype.getDeviceInfo = function(successCallback, errorCallback) {
	cordova.exec(successCallback, errorCallback, "Properpush", "getDeviceInfo", []);
};


Properpush.prototype.openNotificationInAndroidCallback = function (data) {
  try {
    data = JSON.stringify(data)
    console.log('Properpush:openNotificationInAndroidCallback: ' + data)
    this.openNotification = JSON.parse(data)
    cordova.fireDocumentEvent('Properpush.openNotification', this.openNotification)
  } catch(exception) {
    console.log(exception);
  }
}
/**
 * 设置角标及通知
 * badgeNumber:角标数
 * title : 通知标题
 * content:通知正文
 * customDic:通知对应的自定义键值对，这样在打开通知时，在回调函数（openNotificationInAndroidCallback）中会获取到
*/
Properpush.prototype.sendBadgeNotification = function(badgeNumber,title,content,customDic,successCallback, errorCallback) {
    var kvs={};
     kvs['_proper_mpage']='badge';
    if(badgeNumber>=0){
        kvs['_proper_badge']=badgeNumber;
    }else{
        kvs['_proper_badge']=0;
    }
    if(title){
        kvs['_proper_badge_type']='notification';
        kvs['_proper_title']=title;
        if(!content){
            content='';
        }
        kvs['_proper_content']=content;
        kvs['_proper_is_local']=true;//是本地通知标识
    }
    if(customDic){
        for(var k in customDic){
            var v=customDic[k];
            kvs[k]=v;
        }
    }

	cordova.exec(successCallback, errorCallback, "Properpush", "handleSysCmdPush", [kvs]);
};
Properpush.install = function() {
	if(!window.plugins) {
		window.plugins = {};
	}
	window.plugins.properpush = new Properpush();
	return window.plugins.properpush;
};

cordova.addConstructor(Properpush.install);
});
